@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 import os
 import shutil
 
@@ -11,7 +9,7 @@ from . import utils_test
 
 @pytest.yield_fixture
 def fn():
-    filename = '.tmp'
+    filename = ".tmp"
     if os.path.exists(filename):
         shutil.rmtree(filename)
 
@@ -33,12 +31,12 @@ def test_implementation(fn):
     z = File(fn)
     assert not z
 
-    z['x'] = b'123'
-    assert os.listdir(fn) == ['x']
-    with open(os.path.join(fn, 'x'), 'rb') as f:
-        assert f.read() == b'123'
+    z["x"] = b"123"
+    assert os.listdir(fn) == ["x"]
+    with open(os.path.join(fn, "x"), "rb") as f:
+        assert f.read() == b"123"
 
-    assert 'x' in z
+    assert "x" in z
 
 
 def test_str(fn):
@@ -52,31 +50,31 @@ def test_str(fn):
 def test_setitem_typeerror(fn):
     z = File(fn)
     with pytest.raises(TypeError):
-        z['x'] = 123
+        z["x"] = 123
 
 
 def test_contextmanager(fn):
     with File(fn) as z:
-        z['x'] = b'123'
+        z["x"] = b"123"
 
-    with open(os.path.join(fn, 'x'), 'rb') as f:
-        assert f.read() == b'123'
+    with open(os.path.join(fn, "x"), "rb") as f:
+        assert f.read() == b"123"
 
 
 def test_delitem(fn):
     z = File(fn)
 
-    z['x'] = b'123'
-    assert os.path.exists(os.path.join(z.directory, 'x'))
-    del z['x']
-    assert not os.path.exists(os.path.join(z.directory, 'x'))
+    z["x"] = b"123"
+    assert os.path.exists(os.path.join(z.directory, "x"))
+    del z["x"]
+    assert not os.path.exists(os.path.join(z.directory, "x"))
 
 
 def test_missing_key(fn):
     z = File(fn)
 
     with pytest.raises(KeyError):
-        z['x']
+        z["x"]
 
 
 def test_arbitrary_chars(fn):
@@ -85,22 +83,22 @@ def test_arbitrary_chars(fn):
     # Avoid hitting the Windows max filename length
     chunk = 16
     for i in range(1, 128, chunk):
-        key = ''.join(['foo_'] + [chr(i) for i in range(i, min(128, i + chunk))])
+        key = "".join(["foo_"] + [chr(i) for i in range(i, min(128, i + chunk))])
         with pytest.raises(KeyError):
             z[key]
-        z[key] = b'foo'
-        assert z[key] == b'foo'
+        z[key] = b"foo"
+        assert z[key] == b"foo"
         assert list(z) == [key]
         assert list(z.keys()) == [key]
-        assert list(z.items()) == [(key, b'foo')]
-        assert list(z.values()) == [b'foo']
+        assert list(z.items()) == [(key, b"foo")]
+        assert list(z.values()) == [b"foo"]
 
         zz = File(fn)
-        assert zz[key] == b'foo'
+        assert zz[key] == b"foo"
         assert list(zz) == [key]
         assert list(zz.keys()) == [key]
-        assert list(zz.items()) == [(key, b'foo')]
-        assert list(zz.values()) == [b'foo']
+        assert list(zz.items()) == [(key, b"foo")]
+        assert list(zz.values()) == [b"foo"]
         del zz
 
         del z[key]
@@ -111,5 +109,5 @@ def test_arbitrary_chars(fn):
 def test_write_list_of_bytes(fn):
     z = File(fn)
 
-    z['x'] = [b'123', b'4567']
-    assert z['x'] == b'1234567'
+    z["x"] = [b"123", b"4567"]
+    assert z["x"] == b"1234567"
