@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 import gc
 import os
 import shutil
@@ -13,7 +11,7 @@ from . import utils_test
 
 @pytest.yield_fixture
 def fn():
-    dirname = tempfile.mkdtemp(prefix='test_lmdb-')
+    dirname = tempfile.mkdtemp(prefix="test_lmdb-")
     try:
         yield dirname
     finally:
@@ -35,20 +33,20 @@ def test_reuse(fn):
     """
     with LMDB(fn) as z:
         assert len(z) == 0
-        z['abc'] = b'123'
+        z["abc"] = b"123"
 
     with LMDB(fn) as z:
         assert len(z) == 1
-        assert z['abc'] == b'123'
+        assert z["abc"] == b"123"
 
 
 def test_creates_dir(fn):
-    with LMDB(fn) as z:
+    with LMDB(fn):
         assert os.path.isdir(fn)
 
 
 def test_file_descriptors_dont_leak(fn):
-    psutil = pytest.importorskip('psutil')
+    psutil = pytest.importorskip("psutil")
     proc = psutil.Process()
     before = proc.num_fds()
 
